from datetime import datetime
from tools import clean_filename

def get_competition_page_html(self, competition_id):
    competition_data = self.competition_history[competition_id]
    full_competition_name = self.get_full_competition_name(competition_id)
    html_content = f"""<!DOCTYPE html>
    <html lang="en">
    <head>
        <meta charset="UTF-8">
        <meta name="description" content="Results of {full_competition_name}">
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <title>{full_competition_name} - Results</title>
        {self.header_snippet}
        <style>
            body {{
                font-family: Arial, sans-serif;
                line-height: 1.6;
                margin: 0;
                padding: 20px;
                max-width: 1200px;
                margin: 0 auto;
            }}
            h1, h2 {{
                color: #333;
                animation: fadeInUp 0.5s ease-out forwards;
            }}
            h2 {{
                margin-top: 40px;
                margin-bottom: 20px;
            }}
            h3 {{
                color: #555;
                font-weight: normal;
                font-size: 16px;
                margin: 0;
                animation: fadeInUp 0.5s ease-out forwards;
            }}
            table {{
                border-collapse: collapse;
                width: 100%;
                margin-top: 20px;
                box-shadow: 0 4px 6px rgba(0, 0, 0, 0.1);
                border-radius: 5px;
                overflow: hidden;
                animation: fadeInUp 0.5s ease-out forwards;
                opacity: 0;
            }}

            th, td {{
                padding: 12px 15px;
                text-align: left;
            }}

            th {{
                background-color: #f2f2f2;
                color: #333;
                font-weight: bold;
                text-transform: uppercase;
                border-bottom: 2px solid {self.BORDER_COLOR};
            }}

            tr {{
                background-color: white;
                transition: background-color 0.3s ease;
            }}

            tr:nth-child(even) {{
                background-color: #f9f9f9;
            }}

            tr:hover {{
                background-color: #f5f5f5;
            }}
            
            tr:nth-child(even)>td:nth-child(1) {{
                background-color: {self.BORDER_COLOR_DARK};
            }}

            tr:nth-child(odd)>td:nth-child(1) {{
                background-color: {self.BORDER_COLOR};
            }}
            
            td:nth-child(1) {{  
                text-align: center;
                font-weight: bold;
            }}
            
            p {{
                animation: fadeInUp 0.5s ease-out forwards;
            }}
            
            .chart-container {{
                margin-top: 30px;
                display: flex;
                justify-content: center;
                width: 100%;
                animation: fadeInUp 0.5s ease-out forwards;
                opacity: 0;
                box-shadow: 0 4px 10px rgba(0, 0, 0, 0.1);
                border-radius: 5px;
                overflow: hidden;
                background-color: white;
                padding: 20px;
                box-sizing: border-box;
            }}
            
            .chart-container img {{
                max-width: 100%;
                height: auto;
            }}
            
            .sponsor{{
                flex: 1;
                display: flex;
                align-items: center;
                justify-content: center;
                opacity: 75%;
                transition: all 0.3s cubic-bezier(.08,.82,.17,1);
                filter: brightness(calc(1%)) grayscale(100%) contrast(1000%);
                min-width: 113px;
            }}
            
            .sponsor:hover {{
                opacity: 100%;
                filter: none;
            }}
            
            .sponsor img{{
                width: 100%;
                height: auto;
                min-width: 120px;
            }}
            
            .sponsoring-container {{
                margin: 30px 0;
                justify-content: center;
                width: 100%;
                animation: fadeInUp 0.5s ease-out forwards;
                opacity: 0;
                box-shadow: 0 4px 10px rgba(0, 0, 0, 0.1);
                border-radius: 5px;
                overflow: hidden;
                background-color: white;
                box-sizing: border-box;
	            padding-bottom: 30px;
	            padding-left: 45px;
                padding-right: 45px;
            }}
            
            .sponsoring-flex {{
                display: flex;
            	row-gap: 20px;
            	column-gap: 80px;
            	flex-wrap: wrap;         
            }}
            
            a {{
                color: black;
                transition: color 0.3s ease;
            }}
            
            a:hover {{
                color: {self.LINK_COLOR_HOVER};
                text-decoration: none;
            }}
            
            .summary-stats {{
                display: flex;
                justify-content: space-around;
                margin: 20px 0;
                flex-wrap: wrap;
                animation: fadeInUp 0.5s ease-out forwards;
            }}
            
            .stat-box {{
                padding: 15px;
                border: 1px solid #ddd;
                border-radius: 5px;
                margin: 10px;
                flex: 1;
                min-width: 150px;
                text-align: center;
                background-color: #f9f9f9;
            }}
            
            .stat-value {{
                font-size: 24px;
                font-weight: bold;
                color: #333;
            }}
            
            .stat-label {{
                font-size: 14px;
                color: #666;
            }}
            
            .positive {{
                color: green;
            }}
            
            .negative {{
                color: red;
            }}
            
            @keyframes fadeInUp {{
                from {{
                    opacity: 0;
                    transform: translateY(20px);
                }}
                to {{
                    opacity: 1;
                    transform: translateY(0);
                }}
            }}
        </style>
    </head>
    <body>
        <h1>{full_competition_name} - Results</h1>
        <p><a href="../index.html">← Back to World Ranking</a></p>
        
        <div class="sponsoring-container">
            <div style="margin-bottom: 12px; margin-top: 16px; text-align: center">sponsored by:</div>
            <div class="sponsoring-flex">
                <div class="sponsor">
                    <a href="https://murtfeldt.de" target="_blank"><img src="../../murtfeldt.png" alt="Logo of Murtfeldt Kunststoffe"></a>
                </div>
                <div class="sponsor">
                    <a href="https://www.kordel.de" target="_blank"><img src="../../kordel.png" alt="Logo of Kordel"></a>
                </div>
                <div class="sponsor">
                    <a href="https://www.vulcanus-stahl.de/" target="_blank"><img src="../../vulcanus.png" alt="Logo of Vulcanus Stahl"></a>
                </div>
            </div>
        </div>

        <h2>Results</h2>
        <table>
            <tr>
                <th></th>
                <th>Team</th>
                <th>Elo Before</th>
                <th>Elo Change</th>
            </tr>
    """

    # Add rows for each competition
    for team in competition_data['results']:
        elo_change = team[3]
        change_class = "positive" if elo_change > 0 else "negative" if elo_change < 0 else ""

        html_content += f"""
            <tr>
                <td>{team[0]}</td>
                <td><a href="../team/{clean_filename(team[1])}.html">{team[1]}</a></td>
                <td>{int(team[2])}</td>
                <td class="{change_class}">{'+' if elo_change > 0 else ''}{elo_change:.1f}</td>
            </tr>"""

    html_content += f"""
        </table>
        
        <div class="chart-container">
            <img src="../images/{competition_id}_results.{self.IMAGE_FORMAT}" alt="{self.get_full_competition_name(competition_id)} Results">
        </div>

        <p><small>Generated on {datetime.now().strftime("%Y-%m-%d %H:%M:%S")}</small></p>
    </body>
    </html>
    """

    return html_content